@@ -37,9 +37,6 @@
 #include <KSharedConfig>
 #include <KUrlComboBox>
 #include <KUrlRequester>
-#include <KServiceTypeTrader>
-
-#include <kregexpeditorinterface.h>
 
 #include <libkomparediff2/diffsettings.h>
 
@@ -164,23 +161,6 @@ void DiffPage::setDefaults()
     m_excludeFileNameGroupBox->setChecked(false);
 }
 
-void DiffPage::slotShowRegExpEditor()
-{
-    if (! m_ignoreRegExpDialog)
-        m_ignoreRegExpDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>(QStringLiteral("KRegExpEditor/KRegExpEditor"), QString(), this);
-
-    KRegExpEditorInterface* iface = qobject_cast<KRegExpEditorInterface*>(m_ignoreRegExpDialog);
-
-    if (!iface)
-        return;
-
-    iface->setRegExp(m_ignoreRegExpEdit->text());
-    bool ok = m_ignoreRegExpDialog->exec();
-
-    if (ok)
-        m_ignoreRegExpEdit->setText(iface->regExp());
-}
-
 void DiffPage::slotExcludeFilePatternToggled(bool on)
 {
     m_excludeFilePatternEditListBox->setEnabled(on);
@@ -201,7 +181,7 @@ void DiffPage::addDiffTab()
     m_diffProgramGroup = new QGroupBox(page);
     layout->addWidget(m_diffProgramGroup);
     QVBoxLayout* bgLayout = new QVBoxLayout(m_diffProgramGroup);
-    m_diffProgramGroup->setTitle(i18n("Diff Program"));
+    m_diffProgramGroup->setTitle(i18nc("@title:group", "Diff Program"));
 
     // using the "text" property over the "url" property, to also allow plain executable names instead of full path
     m_diffURLRequester = new KUrlRequester(m_diffProgramGroup);
@@ -212,7 +192,7 @@ void DiffPage::addDiffTab()
 
     layout->addStretch(1);
 
-    m_tabWidget->addTab(page, i18n("Diff"));
+    m_tabWidget->addTab(page, i18nc("@title:tab", "Diff"));
 }
 
 void DiffPage::addFormatTab()
@@ -223,18 +203,18 @@ void DiffPage::addFormatTab()
     // add diff modes
     m_modeButtonGroup = new QButtonGroup(page);
     QGroupBox* box = new QGroupBox(page);
-    box->setWhatsThis(i18n("Select the format of the output generated by diff. Unified is the one that is used most frequently because it is very readable. The KDE developers like this format the best so use it for sending patches."));
+    box->setWhatsThis(i18nc("@info:whatsthis", "Select the format of the output generated by diff. Unified is the one that is used most frequently because it is very readable. The KDE developers like this format the best so use it for sending patches."));
     layout->addWidget(box);
     QVBoxLayout* bgLayout = new QVBoxLayout(box);
-    box->setTitle(i18n("Output Format"));
+    box->setTitle(i18nc("@title:group", "Output Format"));
 
-    QRadioButton* radioButton = new QRadioButton(i18n("Context"), box);
+    QRadioButton* radioButton = new QRadioButton(i18nc("@option:radio format type", "Context"), box);
     m_modeButtonGroup->addButton(radioButton, Kompare::Context);
     bgLayout->addWidget(radioButton);
-    radioButton = new QRadioButton(i18n("Normal"),  box);
+    radioButton = new QRadioButton(i18nc("@option:radio format type", "Normal"),  box);
     m_modeButtonGroup->addButton(radioButton, Kompare::Normal);
     bgLayout->addWidget(radioButton);
-    radioButton =  new QRadioButton(i18n("Unified"), box);
+    radioButton =  new QRadioButton(i18nc("@option:radio format type", "Unified"), box);
     m_modeButtonGroup->addButton(radioButton, Kompare::Unified);
     bgLayout->addWidget(radioButton);
 
@@ -242,17 +222,17 @@ void DiffPage::addFormatTab()
     QGroupBox* groupBox = new QGroupBox(page);
     layout->addWidget(groupBox);
     QFormLayout* groupLayout = new QFormLayout(groupBox);
-    groupBox->setTitle(i18n("Lines of Context"));
-    groupBox->setWhatsThis(i18n("The number of context lines is normally 2 or 3. This makes the diff readable and applicable in most cases. More than 3 lines will only bloat the diff unnecessarily."));
+    groupBox->setTitle(i18nc("@title:group", "Lines of Context"));
+    groupBox->setWhatsThis(i18nc("@info:whatsthis", "The number of context lines is normally 2 or 3. This makes the diff readable and applicable in most cases. More than 3 lines will only bloat the diff unnecessarily."));
 
     m_locSpinBox = new QSpinBox(groupBox);
     m_locSpinBox->setRange(0, 100);
-    groupLayout->addRow(i18n("Number of context lines:"), m_locSpinBox);
-    m_locSpinBox->setWhatsThis(i18n("The number of context lines is normally 2 or 3. This makes the diff readable and applicable in most cases. More than 3 lines will only bloat the diff unnecessarily."));
+    groupLayout->addRow(i18nc("@label:spinbox" ,"Number of context lines:"), m_locSpinBox);
+    m_locSpinBox->setWhatsThis(i18nc("@info:whatsthis", "The number of context lines is normally 2 or 3. This makes the diff readable and applicable in most cases. More than 3 lines will only bloat the diff unnecessarily."));
 
     layout->addStretch(1);
 
-    m_tabWidget->addTab(page, i18n("Format"));
+    m_tabWidget->addTab(page, i18nc("@title:tab", "Format"));
 }
 
 void DiffPage::addOptionsTab()
@@ -264,24 +244,24 @@ void DiffPage::addOptionsTab()
     QGroupBox* optionButtonGroup = new QGroupBox(page);
     layout->addWidget(optionButtonGroup);
     QVBoxLayout* bgLayout = new QVBoxLayout(optionButtonGroup);
-    optionButtonGroup->setTitle(i18n("General"));
+    optionButtonGroup->setTitle(i18nc("@title:group", "General"));
 
-    m_newFilesCheckBox    = new QCheckBox(i18n("&Treat new files as empty"), optionButtonGroup);
-    m_newFilesCheckBox->setToolTip(i18n("This option corresponds to the -N diff option."));
-    m_newFilesCheckBox->setWhatsThis(i18n("With this option enabled diff will treat a file that only exists in one of the directories as empty in the other directory. This means that the file is compared with an empty file and because of this will appear as one big insertion or deletion."));
+    m_newFilesCheckBox    = new QCheckBox(i18nc("@option:check", "&Treat new files as empty"), optionButtonGroup);
+    m_newFilesCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -N diff option."));
+    m_newFilesCheckBox->setWhatsThis(i18nc("@info:whatsthis", "With this option enabled diff will treat a file that only exists in one of the directories as empty in the other directory. This means that the file is compared with an empty file and because of this will appear as one big insertion or deletion."));
     bgLayout->addWidget(m_newFilesCheckBox);
 
-    m_smallerCheckBox     = new QCheckBox(i18n("&Look for smaller changes"), optionButtonGroup);
-    m_smallerCheckBox->setToolTip(i18n("This corresponds to the -d diff option."));
-    m_smallerCheckBox->setWhatsThis(i18n("With this option enabled diff will try a little harder (at the cost of more memory) to find fewer changes."));
+    m_smallerCheckBox     = new QCheckBox(i18nc("@option:check", "&Look for smaller changes"), optionButtonGroup);
+    m_smallerCheckBox->setToolTip(i18nc("@info:tooltip", "This corresponds to the -d diff option."));
+    m_smallerCheckBox->setWhatsThis(i18nc("@info:whatsthis", "With this option enabled diff will try a little harder (at the cost of more memory) to find fewer changes."));
     bgLayout->addWidget(m_smallerCheckBox);
-    m_largerCheckBox      = new QCheckBox(i18n("O&ptimize for large files"), optionButtonGroup);
-    m_largerCheckBox->setToolTip(i18n("This corresponds to the -H diff option."));
-    m_largerCheckBox->setWhatsThis(i18n("This option lets diff makes better diffs when using large files. The definition of large is nowhere to be found though."));
+    m_largerCheckBox      = new QCheckBox(i18nc("@option:check", "O&ptimize for large files"), optionButtonGroup);
+    m_largerCheckBox->setToolTip(i18nc("@info:tooltip", "This corresponds to the -H diff option."));
+    m_largerCheckBox->setWhatsThis(i18nc("@info:whatsthis", "This option lets diff makes better diffs when using large files. The definition of large is nowhere to be found though."));
     bgLayout->addWidget(m_largerCheckBox);
-    m_caseCheckBox        = new QCheckBox(i18n("&Ignore changes in case"), optionButtonGroup);
-    m_caseCheckBox->setToolTip(i18n("This corresponds to the -i diff option."));
-    m_caseCheckBox->setWhatsThis(i18n("With this option to ignore changes in case enabled, diff will not indicate a difference when something in one file is changed into SoMEthing in the other file."));
+    m_caseCheckBox        = new QCheckBox(i18nc("@option:check", "&Ignore changes in case"), optionButtonGroup);
+    m_caseCheckBox->setToolTip(i18nc("@info:tooltip", "This corresponds to the -i diff option."));
+    m_caseCheckBox->setWhatsThis(i18nc("@info:whatsthis", "With this option to ignore changes in case enabled, diff will not indicate a difference when something in one file is changed into SoMEthing in the other file."));
     bgLayout->addWidget(m_caseCheckBox);
 
     QHBoxLayout* groupLayout = new QHBoxLayout();
@@ -289,54 +269,44 @@ void DiffPage::addOptionsTab()
     groupLayout->setObjectName(QStringLiteral("regexp_horizontal_layout"));
     groupLayout->setSpacing(-1);
 
-    m_ignoreRegExpCheckBox = new QCheckBox(i18n("Ignore regexp:"), page);
-    m_ignoreRegExpCheckBox->setToolTip(i18n("This option corresponds to the -I diff option."));
-    m_ignoreRegExpCheckBox->setWhatsThis(i18n("When this checkbox is enabled, an option to diff is given that will make diff ignore lines that match the regular expression."));
+    m_ignoreRegExpCheckBox = new QCheckBox(i18nc("@option:check", "Ignore regexp:"), page);
+    m_ignoreRegExpCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -I diff option."));
+    m_ignoreRegExpCheckBox->setWhatsThis(i18nc("@info:whatsthis", "When this checkbox is enabled, an option to diff is given that will make diff ignore lines that match the regular expression."));
     groupLayout->addWidget(m_ignoreRegExpCheckBox);
     m_ignoreRegExpEdit = new KLineEdit(page);
     m_ignoreRegExpEdit->setObjectName(QStringLiteral("regexplineedit"));
-    m_ignoreRegExpEdit->setToolTip(i18n("Add the regular expression here that you want to use\nto ignore lines that match it."));
+    m_ignoreRegExpEdit->setToolTip(i18nc("@info:tooltip", "Add the regular expression here that you want to use\nto ignore lines that match it."));
     groupLayout->addWidget(m_ignoreRegExpEdit);
 
-    if (!KServiceTypeTrader::self()->query(QStringLiteral("KRegExpEditor/KRegExpEditor")).isEmpty())
-    {
-        // Ok editor is available, use it
-        QPushButton* ignoreRegExpEditButton = new QPushButton(i18n("&Edit..."), page);
-        ignoreRegExpEditButton->setObjectName(QStringLiteral("regexp_editor_button"));
-        ignoreRegExpEditButton->setToolTip(i18n("Clicking this will open a regular expression dialog where\nyou can graphically create regular expressions."));
-        groupLayout->addWidget(ignoreRegExpEditButton);
-        connect(ignoreRegExpEditButton, &QPushButton::clicked, this, &DiffPage::slotShowRegExpEditor);
-    }
-
     QGroupBox* moreOptionButtonGroup = new QGroupBox(page);
     layout->addWidget(moreOptionButtonGroup);
     bgLayout = new QVBoxLayout(moreOptionButtonGroup);
-    moreOptionButtonGroup->setTitle(i18n("Whitespace"));
+    moreOptionButtonGroup->setTitle(i18nc("@title:group", "Whitespace"));
 
-    m_tabsCheckBox        = new QCheckBox(i18n("E&xpand tabs to spaces in output"), moreOptionButtonGroup);
-    m_tabsCheckBox->setToolTip(i18n("This option corresponds to the -t diff option."));
-    m_tabsCheckBox->setWhatsThis(i18n("This option does not always produce the right result. Due to this expansion Kompare may have problems applying the change to the destination file."));
+    m_tabsCheckBox        = new QCheckBox(i18nc("@option:check", "E&xpand tabs to spaces in output"), moreOptionButtonGroup);
+    m_tabsCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -t diff option."));
+    m_tabsCheckBox->setWhatsThis(i18nc("@info:whatsthis", "This option does not always produce the right result. Due to this expansion Kompare may have problems applying the change to the destination file."));
     bgLayout->addWidget(m_tabsCheckBox);
-    m_linesCheckBox       = new QCheckBox(i18n("I&gnore added or removed empty lines"), moreOptionButtonGroup);
-    m_linesCheckBox->setToolTip(i18n("This option corresponds to the -B diff option."));
-    m_linesCheckBox->setWhatsThis(i18n("This can be very useful in situations where code has been reorganized and empty lines have been added or removed to improve legibility."));
+    m_linesCheckBox       = new QCheckBox(i18nc("@option:check", "I&gnore added or removed empty lines"), moreOptionButtonGroup);
+    m_linesCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -B diff option."));
+    m_linesCheckBox->setWhatsThis(i18nc("@info:whatsthis", "This can be very useful in situations where code has been reorganized and empty lines have been added or removed to improve legibility."));
     bgLayout->addWidget(m_linesCheckBox);
-    m_whitespaceCheckBox  = new QCheckBox(i18n("Ig&nore changes in the amount of whitespace"), moreOptionButtonGroup);
-    m_whitespaceCheckBox->setToolTip(i18n("This option corresponds to the -b diff option."));
-    m_whitespaceCheckBox->setWhatsThis(i18n("If you are uninterested in differences arising due to, for example, changes in indentation, then use this option."));
+    m_whitespaceCheckBox  = new QCheckBox(i18nc("@option:check", "Ig&nore changes in the amount of whitespace"), moreOptionButtonGroup);
+    m_whitespaceCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -b diff option."));
+    m_whitespaceCheckBox->setWhatsThis(i18nc("@info:whatsthis", "If you are uninterested in differences arising due to, for example, changes in indentation, then use this option."));
     bgLayout->addWidget(m_whitespaceCheckBox);
-    m_allWhitespaceCheckBox = new QCheckBox(i18n("Ign&ore all whitespace"), moreOptionButtonGroup);
-    m_allWhitespaceCheckBox->setToolTip(i18n("This option corresponds to the -w diff option."));
-    m_allWhitespaceCheckBox->setWhatsThis(i18n("This is useful for seeing the significant changes without being overwhelmed by all the white space changes."));
+    m_allWhitespaceCheckBox = new QCheckBox(i18nc("@option:check", "Ign&ore all whitespace"), moreOptionButtonGroup);
+    m_allWhitespaceCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -w diff option."));
+    m_allWhitespaceCheckBox->setWhatsThis(i18nc("@info:whatsthis", "This is useful for seeing the significant changes without being overwhelmed by all the white space changes."));
     bgLayout->addWidget(m_allWhitespaceCheckBox);
-    m_ignoreTabExpansionCheckBox = new QCheckBox(i18n("Igno&re changes due to tab expansion"), moreOptionButtonGroup);
-    m_ignoreTabExpansionCheckBox->setToolTip(i18n("This option corresponds to the -E diff option."));
-    m_ignoreTabExpansionCheckBox->setWhatsThis(i18n("If there is a change because tabs have been expanded into spaces in the other file, then this option will make sure that these do not show up. Kompare currently has some problems applying such changes so be careful when you use this option."));
+    m_ignoreTabExpansionCheckBox = new QCheckBox(i18nc("@option:check", "Igno&re changes due to tab expansion"), moreOptionButtonGroup);
+    m_ignoreTabExpansionCheckBox->setToolTip(i18nc("@info:tooltip", "This option corresponds to the -E diff option."));
+    m_ignoreTabExpansionCheckBox->setWhatsThis(i18nc("@info:whatsthis", "If there is a change because tabs have been expanded into spaces in the other file, then this option will make sure that these do not show up. Kompare currently has some problems applying such changes so be careful when you use this option."));
     bgLayout->addWidget(m_ignoreTabExpansionCheckBox);
 
     layout->addStretch(1);
 
-    m_tabWidget->addTab(page, i18n("Options"));
+    m_tabWidget->addTab(page, i18nc("@title:tab", "Options"));
 }
 
 void DiffPage::addExcludeTab()
@@ -348,14 +318,14 @@ void DiffPage::addExcludeTab()
     m_excludeFilePatternGroupBox->setCheckable(true);
     QHBoxLayout* excludeFileLayout = new QHBoxLayout;
     m_excludeFilePatternGroupBox->setLayout(excludeFileLayout);
-    m_excludeFilePatternGroupBox->setTitle(i18n("File Pattern to Exclude"));
-    m_excludeFilePatternGroupBox->setToolTip(i18n("If this is checked you can enter a shell pattern in the text box on the right or select entries from the list."));
+    m_excludeFilePatternGroupBox->setTitle(i18nc("@title:group", "File Pattern to Exclude"));
+    m_excludeFilePatternGroupBox->setToolTip(i18nc("@info:tooltip", "If this is checked you can enter a shell pattern in the text box on the right or select entries from the list."));
     m_excludeFilePatternEditListBox = new KEditListWidget;
     excludeFileLayout->addWidget(m_excludeFilePatternEditListBox);
     m_excludeFilePatternEditListBox->setObjectName(QStringLiteral("exclude_file_pattern_editlistbox"));
     m_excludeFilePatternEditListBox->setButtons(KEditListWidget::Add | KEditListWidget::Remove);
     m_excludeFilePatternEditListBox->setCheckAtEntering(false);
-    m_excludeFilePatternEditListBox->setToolTip(i18n("Here you can enter or remove a shell pattern or select one or more entries from the list."));
+    m_excludeFilePatternEditListBox->setToolTip(i18nc("@info:tooltip", "Here you can enter or remove a shell pattern or select one or more entries from the list."));
     layout->addWidget(m_excludeFilePatternGroupBox);
 
 
@@ -365,23 +335,23 @@ void DiffPage::addExcludeTab()
     m_excludeFileNameGroupBox->setCheckable(true);
     excludeFileLayout = new QHBoxLayout;
     m_excludeFileNameGroupBox->setLayout(excludeFileLayout);
-    m_excludeFileNameGroupBox->setTitle(i18n("File with Filenames to Exclude"));
-    m_excludeFileNameGroupBox->setToolTip(i18n("If this is checked you can enter a filename in the combo box below."));
+    m_excludeFileNameGroupBox->setTitle(i18nc("@title:group", "File with Filenames to Exclude"));
+    m_excludeFileNameGroupBox->setToolTip(i18nc("@info:tooltip", "If this is checked you can enter a filename in the combo box below."));
     m_excludeFileURLComboBox  = new KUrlComboBox(KUrlComboBox::Files, true);
     excludeFileLayout->addWidget(m_excludeFileURLComboBox);
     m_excludeFileURLComboBox->setObjectName(QStringLiteral("exclude_file_urlcombo"));
-    m_excludeFileURLComboBox->setToolTip(i18n("Here you can enter the URL of a file with shell patterns to ignore during the comparison of the folders."));
+    m_excludeFileURLComboBox->setToolTip(i18nc("@info:tooltip", "Here you can enter the URL of a file with shell patterns to ignore during the comparison of the folders."));
     m_excludeFileURLRequester = new KUrlRequester(m_excludeFileURLComboBox, m_excludeFileNameGroupBox);
     excludeFileLayout->addWidget(m_excludeFileURLRequester);
     m_excludeFileURLRequester->setObjectName(QStringLiteral("exclude_file_name_urlrequester"));
-    m_excludeFileURLRequester->setToolTip(i18n("Any file you select in the dialog that pops up when you click it will be put in the dialog to the left of this button."));
+    m_excludeFileURLRequester->setToolTip(i18nc("@info:tooltip", "Any file you select in the dialog that pops up when you click it will be put in the dialog to the left of this button."));
     layout->addWidget(m_excludeFileNameGroupBox);
 
     connect(m_excludeFileNameGroupBox, &QGroupBox::toggled, this, &DiffPage::slotExcludeFileToggled);
 
     layout->addStretch(1);
 
-    m_tabWidget->addTab(page, i18n("Exclude"));
+    m_tabWidget->addTab(page, i18nc("@title:tab", "Exclude"));
 }
 
 //kate: replace-tabs 0; indent-width 4; tab-width 4;
